@@ -1,15 +1,21 @@
-#! /bin/sh
+#!/bin/sh
 
 #BEGIN DEPEND------------------------------------------------------------------
-INPUT_MODULES='src/lib/perl5/COD/CIF/Data/AtomList.pm'
+INPUT_MODULE=src/lib/perl5/COD/CIF/Data/AtomList.pm
 #END DEPEND--------------------------------------------------------------------
 
-perl <<'END_SCRIPT'
+IMPORT_MODULE=$(\
+    echo ${INPUT_MODULE} | \
+    perl -pe "s|^src/lib/perl5/||; s/[.]pm$//; s|/|::|g;" \
+)
+
+perl -M"${IMPORT_MODULE} qw( atom_groups )" \
+<<'END_SCRIPT'
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2021-07-30 19:52:52 +0300 (Fri, 30 Jul 2021) $
-#$Revision: 8840 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v3.4.0/tests/shtests/cif_disorder_groups_002.sh $
+#$Date: 2024-05-26 17:12:38 +0300 (Sun, 26 May 2024) $
+#$Revision: 10066 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.10.0/tests/shtests/cif_disorder_groups_002.sh $
 #------------------------------------------------------------------------------
 #*
 #  Unit test for the COD::CIF::Data::AtomList module subroutines that deal
@@ -18,7 +24,8 @@ perl <<'END_SCRIPT'
 
 use strict;
 use warnings;
-use COD::CIF::Data::AtomList qw( atom_groups );
+
+# use COD::CIF::Data::AtomList qw( atom_groups );
 
 # Three disorder assemblies, site 'B' has 3 disorder sites, two of
 # which have the same occupancy, but different sizes.
